@@ -35,7 +35,8 @@ display_sars_models <- function() {
 #'   "powerR","epm1","epm2","p1","p2","loga","koba",
 #'   "mmf","monod","negexpo","chapman","weibull3","asymp",
 #'   "ratio","gompertz","weibull4","betap","heleg","linear"), normaTest =
-#'   "lillie", homoTest = "cor.fitted",verb = TRUE)
+#'   "lillie", homoTest = "cor.fitted", grid_start = FALSE, grid_n = NULL,
+#'    verb = TRUE)
 #' @param data A dataset in the form of a dataframe with two columns: the first
 #'   with island/site areas, and the second with the species richness of each
 #'   island/site.
@@ -50,6 +51,11 @@ display_sars_models <- function() {
 #'   the model fitted values; the default), "cor.area" (a correlation of the
 #'   residuals with the area values), or "none" (no residuals homogeneity test
 #'   is undertaken).
+#' @param grid_start Logical argument specifying whether a grid search procedure
+#'   should be implemented to test multiple starting parameter values (default:
+#'   \code{grid_start = FALSE}).
+#' @param grid_n If \code{grid_start = TRUE}, the number of points sampled in
+#'   the model parameter space.
 #' @param verb verbose (default: \code{verb == TRUE}).
 #' @details The \code{sar_models()} function can be used to bring up a list of
 #'   the 20 model names. \code{display_sars_models()} generates a table of the
@@ -78,20 +84,22 @@ sar_multi <- function(data,
                               "linear"),
                       normaTest = "lillie",
                       homoTest = "cor.fitted",
+                      grid_start = FALSE,
+                      grid_n = NULL,
                       verb = TRUE){
-
+  
   if (!((is.character(obj))  | (class(obj) == "sars")) )
     stop("obj must be of class character or sars")
-
+  
   if (nrow(data) < 4)
     stop("Multi SAR needs at least four data points")
   if (nrow(data) == 4 & normaTest == "lillie")
     stop("The Lilliefors test cannot be performed with less than 5 data",
          " points")
-
+  
   if (is.character(obj) & is.null(data))
     stop("if obj is character then data should be provided")
-
+  
   if (is.character(obj)) {
     if (any(!(obj %in% c("linear","power","powerR","epm1","epm2","p1",
                          "p2","loga","koba","mmf","monod","negexpo",
@@ -99,15 +107,22 @@ sar_multi <- function(data,
                          "weibull4","betap","heleg"))))
       stop("provided model names do not match with model functions")
   }
-
+  
+  if (!is.logical(grid_start)) stop("grid_start should be logical")
+  
+  if (grid_start){
+    if (!is.numeric(grid_n)) 
+      stop("grid_n should be numeric if grid_start == TRUE")
+  }
+  
   if (length(obj) < 2)
     stop("more than 1 fit is required to use sar_multi")
-
+  
   normaTest <- match.arg(normaTest, c("none", "shapiro",
                                       "kolmo", "lillie"))
   homoTest <- match.arg(homoTest, c("none","cor.area",
                                     "cor.fitted"))
-
+  
   #if (verb) cat_line(rule(left = paste0(cyan(symbol$bullet),
   #bold(" multi_sars")),right="multi-model SAR"))
   if (verb & is.character(obj)) {
@@ -119,48 +134,61 @@ sar_multi <- function(data,
   #if (verb) cat_line(magenta(symbol$arrow_right)," Data set is: ")
   #if (verb) cat_line(rule(left = paste0(magenta(symbol$bullet))))
   #if (verb) bullet("O | S : model", bullet = blue_arrow())
-
+  
   #if not yet fitted, fit the models to the datasquare_small_filled
   if (!is.character(obj))
     stop("obj should be a character vector of model names")
-
-    mods <- paste0("sar_",obj)
-    names(mods) <- obj
-
-    fits <- suppressWarnings(lapply(obj, function(x){
-
+  
+  mods <- paste0("sar_",obj)
+  names(mods) <- obj
+  
+  fits <- suppressWarnings(lapply(obj, function(x){
+    
+    #have to do separately because linear does not have grid_start;
+    #or if grid_start is set to FALSE
+    if (x == "linear" || !(grid_start)){
       f <- eval(parse(text = paste0(mods[x],
                                     "(data", ", normaTest = ",
                                     paste0("'", normaTest, "'"),
                                     ", homoTest = ", paste0("'", homoTest,
                                                             "'"), ")")))
-
-      if (verb) {
-        if(is.na(f$value)) {
-          cat_line(paste0(red(symbol$arrow_right)," ",
-                           col_align(x,max(nchar(obj)))," : ",
-                           red(symbol$cross)))
+    } else{ #if grid_start provided, implement it (for non-linear models)
+      f <- eval(parse(text = paste0(mods[x],
+                                    "(data", ", normaTest = ",
+                                    paste0("'", normaTest, "'"),
+                                    ", homoTest = ", paste0("'", homoTest,
+                                                            "'"), 
+                                    ", grid_start = ", 
+                                    paste0(grid_start), ", grid_n = ",
+                                    paste0(grid_n),")")))
+    }
+    
+    if (verb) {
+      if(is.na(f$value)) {
+        cat_line(paste0(red(symbol$arrow_right)," ",
+                        col_align(x,max(nchar(obj)))," : ",
+                        red(symbol$cross)))
+      }else{
+        
+        if (!is.matrix(f$sigConf)){
+          cat_line( paste0(yellow(symbol$arrow_right)," ",
+                           col_align(x,max(nchar(obj))),
+                           " : Warning: could not compute parameters statistics"))
         }else{
-
-          if (!is.matrix(f$sigConf)){
-            cat_line( paste0(yellow(symbol$arrow_right)," ",
-                             col_align(x,max(nchar(obj))),
-                        " : Warning: could not compute parameters statistics"))
-          }else{
-            cat_line( paste0(cyan(symbol$arrow_right)," ",
-                             col_align(x,max(nchar(obj)))," : ",
-                             green(symbol$tick)))
-          }
+          cat_line( paste0(cyan(symbol$arrow_right)," ",
+                           col_align(x,max(nchar(obj)))," : ",
+                           green(symbol$tick)))
         }
       }
-
-      f
-
-    }))#eo suppressWarnings(lapply)
-    names(fits) <- obj
-    class(fits) <- "sars"
-    attr(fits, "type") <- "fit_collection"
-    return(fits)
+    }
+    
+    f
+    
+  }))#eo suppressWarnings(lapply)
+  names(fits) <- obj
+  class(fits) <- "sars"
+  attr(fits, "type") <- "fit_collection"
+  return(fits)
 }#end of multi_sars
 
 
@@ -173,8 +201,8 @@ sar_multi <- function(data,
 #'   "mmf","monod","negexpo","chapman","weibull3","asymp",
 #'   "ratio","gompertz","weibull4","betap","heleg", "linear"), data = NULL, crit
 #'   = "Info", normaTest = "lillie", homoTest = "cor.fitted", neg_check = FALSE,
-#'   alpha_normtest = 0.05, alpha_homotest = 0.05, confInt = FALSE, ciN = 100,
-#'   verb = TRUE)
+#'   alpha_normtest = 0.05, alpha_homotest = 0.05, grid_start = FALSE,
+#'   grid_n = NULL, confInt = FALSE, ciN = 100, verb = TRUE)
 #' @param obj Either a vector of model names or a fit_collection object created
 #'   using \code{\link{sar_multi}}. If a vector of names is provided,
 #'   \code{sar_average} first calls \code{sar_multi} before generating the
@@ -206,6 +234,12 @@ sar_multi <- function(data,
 #' @param alpha_homotest The alpha value used in the residual homogeneity test
 #'   (default = 0.05, i.e. any test with a P value < 0.05 is flagged as failing
 #'   the test).
+#' @param grid_start Logical argument specifying whether a grid search procedure
+#'   should be implemented to test multiple starting parameter values. The
+#'   default is set to FALSE, but we would recommend using it to ensure the fits
+#'   of certain models (e.g. Gompertz, Chapman Richards) are optimal.
+#' @param grid_n If \code{grid_start = TRUE}, the number of points sampled in
+#'   the model parameter space.
 #' @param confInt A logical argument specifying whether confidence intervals
 #'   should be calculated for the multimodel curve using bootstrapping.
 #' @param ciN The number of bootstrap samples to be drawn to calculate the
@@ -272,11 +306,37 @@ sar_multi <- function(data,
 #'   the resultant 'multi' object to check the individual model fits. To re-run
 #'   the \code{sar_multi} function without a particular model, simply remove it
 #'   from the \code{obj} argument.
+#'   
+#'   Choosing starting parameter values for non-linear regression optimisation
+#'   algorithms is not always straight forward, depending on the data at hand.
+#'   In the package, we use various approaches to choose default starting
+#'   parameters. However, if any of the resultant model fits does not converge,
+#'   returns a singular gradient at parameter estimates, or the plot of the
+#'   model fit does not look optimum, try using the \code{grid_start} argument
+#'   to undertake a more extensive selection of starting values, or provide your
+#'   own starting values (\code{start}). While using \code{grid_start} is more
+#'   time consuming, it will often provide (much) better fits for certain
+#'   models, and so we recommend its use where possible. Note, that
+#'   \code{grid_start} has been disabled for a small number of models (e.g.
+#'   Weibull 3 par.). See the vignette for more information.
 #'
 #'   The generation of confidence intervals around the multimodel curve (using
 #'   \code{confInt == TRUE}), may throw up errors that we have yet to come
 #'   across. Please report any issues to the package maintainer.
-#'
+#'   
+#'   There are different formulas for calculating the various information
+#'   criteria (IC) used for model comparison (e.g. AIC, BIC). For example, some
+#'   formulas use the residual sum of squares (rss) and others the
+#'   log-likelihood (ll). Both are valid approaches and will give the same
+#'   parameter estimates, but it is important to only compare IC values that
+#'   have been calculated using the same approach. For example, the 'sars'
+#'   package used to use formulas based on the rss, while the \link[stats]{nls}
+#'   function function in the stats package uses formulas based on the ll. To
+#'   increase the compatability between nls and sars, we have changed our
+#'   formulas such that now our IC formulas are the same as those used in the
+#'   \link[stats]{nls} function. See the "On the calculation of information
+#'   criteria" section in the package vignette for more information.
+#'   
 #' @references Burnham, K. P., & Anderson, D. R. (2002). Model selection and
 #'   multi-model inference: a practical information-theoretic approach (2nd
 #'   ed.). New-York: Springer.
@@ -303,22 +363,24 @@ sar_average <- function(obj = c("power", "powerR","epm1","epm2","p1","p2",
                                 "chapman","weibull3","asymp","ratio",
                                 "gompertz", "weibull4","betap","heleg",
                                 "linear"), data = NULL,
-                      crit = "Info",
-                      normaTest = "lillie",
-                      homoTest = "cor.fitted",
-                      neg_check = FALSE,
-                      alpha_normtest = 0.05,
-                      alpha_homotest = 0.05,
-                      confInt = FALSE,
-                      ciN = 100,
-                      verb = TRUE){
-
+                        crit = "Info",
+                        normaTest = "lillie",
+                        homoTest = "cor.fitted",
+                        neg_check = FALSE,
+                        alpha_normtest = 0.05,
+                        alpha_homotest = 0.05,
+                        grid_start = FALSE,
+                        grid_n = NULL,
+                        confInt = FALSE,
+                        ciN = 100,
+                        verb = TRUE){
+  
   if (!((is.character(obj))  | (class(obj) == "sars")) )
     stop("obj must be of class character or sars")
-
+  
   if (is.character(obj) & is.null(data))
     stop("if obj is character then data should be provided")
-
+  
   if (is.character(obj)) {
     if (any(!(obj %in% c("linear","power","powerR","epm1","epm2","p1",
                          "p2","loga","koba","mmf","monod","negexpo",
@@ -326,15 +388,25 @@ sar_average <- function(obj = c("power", "powerR","epm1","epm2","p1","p2",
                          "weibull4","betap","heleg"))))
       stop("provided model names do not match with model functions")
   }
-
+  
+  if (!is.logical(grid_start)) stop("grid_start should be logical")
+  
+  if (grid_start){
+    if (!is.numeric(grid_n)) 
+      stop("grid_n should be numeric if grid_start == TRUE")
+  }
+  
   if (length(obj) < 2)
     stop("more than 1 fit is required to construct a sar_multi")
-
+  
   #if a vector of names is provided, then call sar_multi first
   if (is.character(obj)){
     fits <- sar_multi(data = data, obj = obj,
-                                            normaTest = normaTest,
-                                            homoTest = homoTest, verb = verb)
+                      normaTest = normaTest,
+                      homoTest = homoTest, 
+                      grid_start = grid_start,
+                      grid_n = grid_n,
+                      verb = verb)
   } else{
     fits <- obj
   }
@@ -566,7 +638,10 @@ sar_average <- function(obj = c("power", "powerR","epm1","epm2","p1","p2",
                         homoTest = homoTest,
                         neg_check = neg_check,
                         alpha_normtest = alpha_normtest,
-                        alpha_homotest = alpha_homotest, verb = verb)
+                        alpha_homotest = alpha_homotest, 
+                        grid_start = grid_start,
+                        grid_n = grid_n,
+                        verb = verb)
     res$details$confInt <- cis
   } else {
     res$details$confInt <- NA
@@ -590,9 +665,9 @@ sar_average <- function(obj = c("power", "powerR","epm1","epm2","p1","p2",
 #' @details Extrapolation (e.g. predicting the richness of areas too large to be
 #'   sampled) is one of the primary uses of the SAR. The \code{sar_pred}
 #'   function provides an easy method for undertaking such an exercise. The
-#'   function works by taking an already fitted SAR model, extacting the parameter
-#'   values and then using these values and the model function to predict the
-#'   richness for any value of area provided.
+#'   function works by taking an already fitted SAR model, extacting the
+#'   parameter values and then using these values and the model function to
+#'   predict the richness for any value of area provided.
 #'
 #'   If a multi-model SAR curve is used for prediction (i.e. using
 #'   \code{\link{sar_average}}), the model information criterion weight (i.e.
